@@ -5,13 +5,13 @@ from sqlalchemy import JSON, Column, ForeignKey
 from sqlalchemy.orm import relationship
 from sqlalchemy.sql.schema import UniqueConstraint
 
-from fief.models.base import AccountBase
+from fief.models.base import WorkspaceBase
 from fief.models.client import Client
 from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
 from fief.models.user import User
 
 
-class Grant(UUIDModel, CreatedUpdatedAt, AccountBase):
+class Grant(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     __tablename__ = "grants"
     __table_args__ = (UniqueConstraint("user_id", "client_id"),)
 
